4.54. umbra.ui.widgets.delayed_QSplashScreen — Umbra 1.0.9 documentation

# 4.54. umbra.ui.widgets.delayed_QSplashScreen

delayed_QSplashScreen.py

Platform:
  Windows, Linux, Mac Os X.
Description:
  Defines the `Delayed_QSplashScreen` class.

Others:

## 4.54.1. Module Attributes

`umbra.ui.widgets.delayed_QSplashScreen.` `LOGGER`

## 4.54.2. Classes

class `umbra.ui.widgets.delayed_QSplashScreen.` `Delayed_QSplashScreen`(pixmap, waitTime=0, textColor=2, *args, **kwargs)

  Bases: `PyQt4.QtGui.QSplashScreen`

  Defines a QSplashScreen subclass providing delayed messages capabilities.

  Initializes the class.

  Parameters: | pixmap (unicode) – Current pixmap path. waitTime (int) – wait time. *args (*) – Arguments. **kwargs (**) – Keywords arguments.

  `waitTime`

    Property for self.__waitTime attribute.

    Returns: | self.__waitTime
    Return type: | int or float

  `textColor`

    Property for self.__textColor attribute.

    Returns: | self.__textColor
    Return type: | int or QColor

  `showMessage`(message, textAlignement=1, textColor=None, waitTime=None)

    Reimplements the `QSplashScreen.showMessage()` method.

    Parameters: | message (unicode) – Message to display on the splashscreen. textAlignement (object) – Text message alignment. textColor (object) – Text message color. waitTime (int) – Wait time.